@@ -71,7 +71,8 @@ class UserManager(BaseUserManager):
             _oldValues = oldValues
 
         data = self._remove_prop_(data)
-        values = [item for item in dictinct_list(_oldValues) - set(data) if not item.startswith('_')]
+        values = [item for item in dictinct_list(set(_oldValues) - set(data)) if not item.startswith('_')]
+        # values = [item for item in list(set(_oldValues) - set(data)) if not item.startswith('_')]
         for item in values:
             setAttr(data, item, None)
 
